=======
History
=======

0.1.0 (2016-09-24)
------------------

* First release on PyPI.

0.2.0 (2016-09-25)
------------------

* More safety checks in configuration
* Added the ``every_n`` parameter to ``noterate``

0.2.1 (2016-09-25)
------------------

* More appropriate exception usage in config loading / checking
